The **sklearn-weka-plugin** library integrates `Weka <http://www.cs.waikato.ac.nz/~ml/weka/>`__ algorithms
in scikit-learn using Python 3. It makes use of the `python-weka-wrapper3 <https://github.com/fracpete/python-weka-wrapper3>`__
library for handling the Java Virtual Machine.

Examples can be found at:

https://github.com/fracpete/sklearn-weka-plugin-examples
